==> haskell-network-multicast-0.3.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-EWpcGWGtak4GqrGKIouBtk
key:                  network-multicast-0.3.2-EWpcGWGtak4GqrGKIouBtk
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  0e56ff9bdecfbf64332ee35b391564be
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-8.10.1/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/network-multicast-0.3.2
hs-libraries:         HSnetwork-multicast-0.3.2-EWpcGWGtak4GqrGKIouBtk
depends:
    base-4.14.0.0 network-3.1.1.1-21cfXONzmdN6SdhuDmk3jf
    network-bsd-2.8.1.0-LW0btMZmSB9IBMSOak1kd

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.3.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-927evNjsrlF4AHwFCXMzBn
key:                  network-multicast-0.3.2-927evNjsrlF4AHwFCXMzBn
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  3666ee7290678bb6e08febf1768ee46b
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-8.10.1/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/network-multicast-0.3.2
hs-libraries:         HSnetwork-multicast-0.3.2-927evNjsrlF4AHwFCXMzBn
depends:
    base-4.14.0.0 network-3.1.1.1-AsQXXcxnCbFJ7gfp84UdJt
    network-bsd-2.8.1.0-CN30SSwWhefPthOJyO0h0

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
